Position class abstract

Available extensions
Annotations
  • @freezed

Constructors

Position({required int? id, required String? name, required String? roleId, required DateTime? createdDate})
const
factory
Position.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $PositionCopyWith<Position>
Create a copy of Position with the given fields replaced by the non-null parameter values.
no setterinherited
createdDate → DateTime?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int?
no setterinherited
name → String?
no setterinherited
roleId → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Position value)) → TResult

Available on Position, provided by the PositionPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Position value)?) → TResult?

Available on Position, provided by the PositionPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Position value)?, {required TResult orElse()}) → TResult

Available on Position, provided by the PositionPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int? id, String? name, String? roleId, DateTime? createdDate)?, {required TResult orElse()}) → TResult

Available on Position, provided by the PositionPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this Position to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(int? id, String? name, String? roleId, DateTime? createdDate)) → TResult

Available on Position, provided by the PositionPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int? id, String? name, String? roleId, DateTime? createdDate)?) → TResult?

Available on Position, provided by the PositionPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited