AreaService class

Constructors

AreaService({required ApiClient apiClient, FirebaseCrashlytics? crashlytics})
Constructor for the AreaService

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDepotByInternalArea(int internalAreaId) → Future<List<Depot>>
Get the depots by internal areas from the server
getDepotByRegionalArea(int regionalAreaId) → Future<List<Depot>>
Get the depots by regional areas from the server
getInternalAreas(int regionalAreaId) → Future<List<InternalArea>>
Get the internal areas from the server
getIslandGroups() → Future<List<IslandGroup>>
Get the island groups from the server
getRegionalAreas(int islandGroupId) → Future<List<RegionalArea>>
Get the regional areas from the server
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited